ChannelId

Struct ChannelId 

pub struct ChannelId { /* private fields */ }
Available on crate feature api only.
A unique and opaque identifier for a channel over the websocket.

Implementations

Source

impl ChannelId

pub const NONE: Self

The channel id used for an invalid channel.

pub const fn from_u16(repr: u16) -> Self

Construct a new channel id from a raw u16 representation.

Note that this does not guarantee that the internal representation of a channel identifier is exactly a u16, only that at least u16 unique identifiers can be constructed.

Using 0 is equivalent to ChannelId::NONE. When implementing a custom ChannelAllocator the allocator must avoid constructor identifiers with this value since it is equivalent to no channel.

Examples
use musli_web::api::ChannelId;
let id = ChannelId::from_u16(0);
assert_eq!(id, ChannelId::NONE);