pub struct MessageId(/* private fields */);Available on crate feature
api only.Expand description
A raw identifier for a message.
Implementations
Sourceimpl MessageId
impl MessageId
Sourcepub const ERROR_MESSAGE: Self
pub const ERROR_MESSAGE: Self
The message id for [ErrorMessage].
Sourcepub const DISCONNECT: Self
pub const DISCONNECT: Self
A clean disconnect of a channel.
Sourcepub const SERVER_HELLO: Self
pub const SERVER_HELLO: Self
The first message the server sends to indicat that a connection is open.
Sourcepub const NEGOTIATE: Self
pub const NEGOTIATE: Self
A request from the client to use a particular Format for the
remainder of the connection.
See the [negotiation protocol] for how this is used.
Sourcepub const EMPTY: Self
pub const EMPTY: Self
The message id for an empty packet constructed using Packet::empty
or RawPacket::empty.
Examples
use musli_web::api::MessageId;
use musli_web::web::{RawPacket, Packet};
let packet = RawPacket::empty();
assert_eq!(packet.id(), MessageId::EMPTY);
let packet = Packet::<()>::empty();
assert_eq!(packet.id(), MessageId::EMPTY);Sourcepub const unsafe fn new_unchecked(id: u16) -> Self
pub const unsafe fn new_unchecked(id: u16) -> Self