pub struct Channel { /* private fields */ }Available on crate feature
client only.Expand description
A channel to a websocket server.
See Handle::channel for more details.
Dropping this cleanly disconnects the channel, which is signalled to the
server through Handler::close_channel.
Implementations
Sourceimpl Channel
impl Channel
Sourcepub fn handle(&self) -> Handle
pub fn handle(&self) -> Handle
Get a handle associated with this channel.
A handle sheds the channel information and allows for setting up things like broadcast listeners.
Sourcepub fn request(&self) -> RequestBuilder<'_, EmptyBody>
pub fn request(&self) -> RequestBuilder<'_, EmptyBody>
Send a request over the current channel.
See RequestBuilder::send for how the request is completed.