pub struct Error { /* private fields */ }Available on crate feature
client only.Expand description
Error type for the client.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn is_empty_packet(&self) -> bool
pub fn is_empty_packet(&self) -> bool
Check if the error is caused by an empty packet.
Examples
use musli_web::client::RawPacket;
let packet = RawPacket::empty();
let e = packet.decode::<u32>().unwrap_err();
assert!(e.is_empty_packet());Sourcepub fn is_not_connected(&self) -> bool
pub fn is_not_connected(&self) -> bool
Check if the error is caused by the connection not being open.
This is the error which is produced if a request is performed while the
service is not connected. See Handle::wait_until_open for how to
wait until the connection is available.
Sourcepub fn as_server_error(&self) -> Option<&str>
pub fn as_server_error(&self) -> Option<&str>
Check if the error is a server error, and if so return the message reported by the server.
Server errors are produced by a Handler which returns an error or
which indicates that it does not support the request being made.