Listener

Struct Listener 

pub struct Listener<T> { /* private fields */ }
Available on crate feature client only.
A listener for broadcasts of type T.

Constructed through Handle::on_broadcast. Dropping this removes the listener.

Implementations

Source

impl<T> Listener<T>

pub async fn recv_raw(&mut self) -> Option<Result<RawPacket, Error>>

Receive the next raw broadcast.

Returns None if the service has been shut down.

pub async fn recv(&mut self) -> Option<Result<Packet<T>, Error>>

Receive the next broadcast.

Returns None if the service has been shut down.

pub fn clear(&mut self)

Clear the listener without dropping it.

This removes the associated listener from being notified. Any broadcasts which have already been buffered can still be received, after which Listener::recv returns None.