Service

Struct Service 

pub struct Service<T>
where T: ClientImpl,
{ /* private fields */ }
Available on crate feature client only.
The service which drives a connection.

This is constructed through connect() and has to be driven by calling Service::run.

Implementations

Source

impl<T> Service<T>
where T: ClientImpl,

pub fn handle(&self) -> &Handle

Get a handle to the service.

The returned handle can be cloned and moved freely between tasks.

pub async fn run(&mut self) -> Result<(), Error>

Run the service.

This drives the underlying connection and must be called for any requests to be processed. It is typically spawned onto a task of its own.

Unless disabled through ServiceBuilder::reconnect, a connection which is lost is re-established with an exponential backoff. Any requests which were in flight at that point are failed.

This returns once Handle::close has been called, or the connection has been lost while reconnecting is disabled.