ServiceBuilder

Struct ServiceBuilder 

pub struct ServiceBuilder<T, E> { /* private fields */ }
Available on crate feature client only.
Builder of a Service.

Constructed through connect().

Implementations

Source

impl<T, E> ServiceBuilder<T, E>
where T: ClientImpl, E: Callback<Error>,

pub fn on_error<U>(self, on_error: U) -> ServiceBuilder<T, U>
where U: Callback<Error>,

Set the error handler to use for the service.

Errors which are reported here are errors which cannot be associated with a particular request, such as a failure to connect or a message which could not be decoded.

pub fn format(self, format: Format) -> Self

Set the Format to use for message bodies.

The format is negotiated with the server once the connection is established, see the negotiation protocol. If the server does not support it the error is reported through ServiceBuilder::on_error and the connection falls back to Format::DEFAULT, which can be observed through Handle::format.

Defaults to Format::DEFAULT.

pub fn reconnect(self, reconnect: bool) -> Self

Configure whether the service should try to reconnect when the connection is lost.

This defaults to true. If this is disabled, Service::run returns once the connection has been lost or could not be established.

pub fn seed(self, seed: u64) -> Self

Associate the specified seed with the service.

This affects the random fuzzing which is applied to reconnect timeouts.

By default the seed is a constant value.

pub fn build(self) -> Service<T>

Build the service.

Note that no connection is established until Service::run is called.