StateListener

Struct StateListener 

pub struct StateListener { /* private fields */ }
Available on crate feature client only.
A listener for state changes.

Constructed through Handle::on_state_change.

Implementations

Source

impl StateListener

pub fn state(&self) -> State

Get the most recently observed state.

pub async fn changed(&mut self) -> Option<State>

Wait for the state to change and return the new state.

Returns None if the Service driving the connection is gone.

pub async fn wait_until(&mut self, state: State) -> bool

Wait until the observed state is state.

Returns false if the Service driving the connection is gone before the state could be observed.