Service

Struct Service 

pub struct Service<H>
where H: WebImpl,
{ /* private fields */ }
Available on crate feature web03 only.
The service handle.

Once dropped this will cause the service to be disconnected and all requests to be cancelled.

Implementations

Source

impl<H> Service<H>
where H: WebImpl,

pub fn connect(&self)

👎Deprecated since 0.3.0:

Use open instead

Attempt to establish a WebSocket connection.

pub fn open(&self)

Open the WebSocket connection.

Calling this method indicates that the connection should stay open, and the implementation will attempt to reconnect until Service::close is called.

pub fn close(&self)

Close the WebSocket connection.

This is not strictly necessary, but some browsers like Firefox might be slow to recycle the connection unless it has been explicitly closed.

It is generally recommended that you call this when beforeunload on window is fired.

pub fn handle(&self) -> &Handle<H>

Return the handle to the service.

A Handle instances does not force the underlying WebSocket to stay connected, and is invalidated when Service is destructed.