pub struct Channels { /* private fields */ }Available on crate feature
ws only.Expand description
A global channel allocator which can be cloned and re-used across multiple servers allowing channels across servers to have distinct channel identifiers.