pub struct ChannelId { /* private fields */ }Available on crate feature
api only.Expand description
A unique and opaque identifier for a channel over the websocket.
Implementations
Sourceimpl ChannelId
impl ChannelId
Sourcepub const fn from_u16(repr: u16) -> Self
pub const fn from_u16(repr: u16) -> Self
Construct a new channel id from a raw u16 representation.
Note that this does not guarantee that the internal representation of a
channel identifier is exactly a u16, only that at least u16 unique
identifiers can be constructed.
Using 0 is equivalent to ChannelId::NONE. When implementing a
custom ChannelAllocator the allocator must avoid constructor
identifiers with this value since it is equivalent to no channel.
Examples
use musli_web::api::ChannelId;
let id = ChannelId::from_u16(0);
assert_eq!(id, ChannelId::NONE);Trait Implementations
impl Copy for ChannelId
Sourceimpl<'__de, __A> Decode<'__de, Binary, __A> for ChannelIdwhere
__A: Allocator,
impl<'__de, __A> Decode<'__de, Binary, __A> for ChannelIdwhere
__A: Allocator,
Sourceconst IS_BITWISE_DECODE: bool = false
const IS_BITWISE_DECODE: bool = false
Whether the type is packed. Packed types can be bitwise copied if the
representation of the serialization format is identical to the memory
layout of the type. Read more
Sourceimpl<'__de, __A> Decode<'__de, Text, __A> for ChannelIdwhere
__A: Allocator,
impl<'__de, __A> Decode<'__de, Text, __A> for ChannelIdwhere
__A: Allocator,
Sourceconst IS_BITWISE_DECODE: bool = false
const IS_BITWISE_DECODE: bool = false
Whether the type is packed. Packed types can be bitwise copied if the
representation of the serialization format is identical to the memory
layout of the type. Read more
Sourceimpl Encode<Binary> for ChannelId
impl Encode<Binary> for ChannelId
Sourceconst IS_BITWISE_ENCODE: bool = false
const IS_BITWISE_ENCODE: bool = false
Whether the type is packed. Packed types can be bitwise copied if the
representation of the serialization format is identical to the memory
layout of the type. Read more
Sourceimpl Encode<Text> for ChannelId
impl Encode<Text> for ChannelId
Sourceconst IS_BITWISE_ENCODE: bool = false
const IS_BITWISE_ENCODE: bool = false
Whether the type is packed. Packed types can be bitwise copied if the
representation of the serialization format is identical to the memory
layout of the type. Read more
impl Eq for ChannelId
Sourceimpl From<ChannelId> for AtomicChannelId
impl From<ChannelId> for AtomicChannelId
Sourceimpl Ord for ChannelId
impl Ord for ChannelId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ChannelId
impl PartialOrd for ChannelId
impl StructuralPartialEq for ChannelId