pub trait DecodeBody<'de>{ }Available on crate feature
api only.Expand description
Types which can be decoded in every mode that this crate supports.
This is a blanket trait covering Decode in both the Binary and
Text modes, which is what allows a message body to be decoded with any
Format including Format::Json.
Deriving Decode implements every mode, so this is implemented
automatically unless the type has been restricted to a specific mode.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".