pub struct Listener<T> { /* private fields */ }Available on crate feature
client only.Expand description
A listener for broadcasts of type T.
Constructed through Handle::on_broadcast. Dropping this removes the
listener.
Implementations
Sourceimpl<T> Listener<T>
impl<T> Listener<T>
Sourcepub async fn recv_raw(&mut self) -> Option<Result<RawPacket, Error>>
pub async fn recv_raw(&mut self) -> Option<Result<RawPacket, Error>>
Receive the next raw broadcast.
Returns None if the service has been shut down.
Sourcepub async fn recv(&mut self) -> Option<Result<Packet<T>, Error>>
pub async fn recv(&mut self) -> Option<Result<Packet<T>, Error>>
Receive the next broadcast.
Returns None if the service has been shut down.
Sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Clear the listener without dropping it.
This removes the associated listener from being notified. Any broadcasts
which have already been buffered can still be received, after which
Listener::recv returns None.