pub struct Service<H>where
H: WebImpl,{ /* private fields */ }Available on crate feature
web03 only.Expand description
The service handle.
Once dropped this will cause the service to be disconnected and all requests to be cancelled.
Implementations
Sourceimpl<H> Service<H>where
H: WebImpl,
impl<H> Service<H>where
H: WebImpl,
Sourcepub fn connect(&self)
👎Deprecated since 0.3.0: Use open instead
pub fn connect(&self)
Use open instead
Attempt to establish a WebSocket connection.
Sourcepub fn open(&self)
pub fn open(&self)
Open the WebSocket connection.
Calling this method indicates that the connection should stay open, and
the implementation will attempt to reconnect until Service::close is
called.